{% extends "appbuilder/base.html" %}
{% block head_css %}
{{ super() }}
<link href="{{url_for('Airflow Balancer.static',filename='css/index.css')}}" rel="stylesheet">
{% endblock %}

{% block head_js %}
{{ super() }}
<script>
    window.__AIRFLOW_BALANCER_CONFIG__ = `{{ config|safe }}`;
</script>
<script src="{{url_for('Airflow Balancer.static', filename='cdn/index.js')}}" nonce="{{baselib.get_nonce()}}"></script>
{% endblock %}


{% block content %}
    <h1>Balancer</h1>
    <div id="airflow-balancer-root"></div>
{% endblock %}
